//
//  TestVideoViewController.m
//  PokktManager
//
//  Created by Pokkt on 3/2/15.
//  Copyright (c) 2015 Pokkt. All rights reserved.
//

#import "TestVideoViewController.h"
#import "AppDelegate.h"
#import "PokktManager.h"
#import "PokktController.h"
#import "VideoResponse.h"

#define ErnedPoints @"Points"
#define userDefaluts [NSUserDefaults standardUserDefaults]

@interface TestVideoViewController ()<PokktDelegate>
@property (nonatomic, strong) AppDelegate *appdelegate;

@property (nonatomic ,strong) PokktManager *manager;
@property (nonatomic) int point;

@end

@implementation TestVideoViewController

- (void)viewDidLoad {
    [super viewDidLoad];
   
    self.appdelegate = [UIApplication sharedApplication].delegate;
    [PokktManager setDebugger:YES];
    self.manager = [PokktManager sharedInstance];
    [self.manager setSkipVideo:YES];
    [self.manager setDefaultSkipTime:10];
    [self.manager setPresentView:self];
    [self.manager setPokktDelegate:self];
    [self updatepointsEarned];
    
//    [[NSNotificationCenter defaultCenter] addObserverForName:UIApplicationDidBecomeActiveNotification object:nil queue:[NSOperationQueue mainQueue] usingBlock:^(NSNotification *note) {
//        [self.manager playVideoFromDidBecomeActive];
//    }];
    [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(playVideo) name:UIApplicationDidBecomeActiveNotification object:nil];

    // Do any additional setup after loading the view.
}

- (void)playVideo {
    [[NSNotificationCenter defaultCenter] postNotificationName:@"app" object:nil];
//    [PokktManager playVideoFromDidBecomeActive];

}

-(void)viewWillAppear:(BOOL)animated{
    [super viewWillAppear:animated];
    [self showButton:NO];
    [self.navigationController setNavigationBarHidden:YES];   //it hides
//    [self.manager cacheVideoCampaign];
}

-(void)viewWillDisappear:(BOOL)animated{
    [super viewWillDisappear:animated];
    [self.navigationController setNavigationBarHidden:NO];    // it shows
}
- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

#pragma mark - Button Action

- (IBAction)plaVdoButtonActions:(UIButton *)sender {
    
    if (sender.tag == 1)
    {
        [self.manager playVideoCampaign:YES];
        
    }
    else if (sender.tag == 2)
    {
        [self.manager playVideoCampaign:NO];
    }
    else if(sender.tag == 3)
    {
        if (![self.manager isVideoAvailable])
        {
            [self performSegueWithIdentifier:@"StaticPage" sender:self];
        }
        else
        {
            [self.manager playVideoCampaign:NO];
        }
    }
}

#pragma mark - Private Methods

- (void)updatepointsEarned {
    if([userDefaluts objectForKey:ErnedPoints]) {
        self.point = [[userDefaluts objectForKey:ErnedPoints] intValue];
        self.pointsCountLbl.text = [NSString stringWithFormat:@"Points earned : %d",self.point];
    }
}

- (void)showButton:(BOOL)show {
    self.playIncentVdoBtn.hidden = !show;
    self.playNonIncentVdoBtn.hidden = !show;
}

- (void)showAlertWithMessage:(NSString *)msg {
    UIAlertView *alert = [[UIAlertView alloc]initWithTitle:@"" message:msg delegate:nil cancelButtonTitle:@"OK" otherButtonTitles:nil];
    [alert show];
}

#pragma mark - Pokkt Delegates

- (void)didFinishedVideoDownload:(BOOL)isFinished {
    [self.playIncentVdoBtn setTitle:[NSString stringWithFormat:@"Play Incent Vdo To Earn %@",self.manager.videoVC] forState:UIControlStateNormal];
    [self showButton:YES];
}

- (void)didFailedVideoDownload:(NSError *)error {
    [self showButton:NO];
}

- (void)onVideoClosed:(BOOL)isClosed {
    [self showAlertWithMessage:@"Video is closed"];
}

- (void)onVideoCompleated:(BOOL)isCompleated {
    [self showAlertWithMessage:@"Video is compleated"];
}

- (void)onVideoDisplayed  {
    [self showAlertWithMessage:@"Video is displayed"];
}

- (void)onVideoGratified:(VideoResponse *)videoResponse {
    if([userDefaluts objectForKey:ErnedPoints]) {
        self.point = [[userDefaluts objectForKey:ErnedPoints] intValue];
    }
    if (videoResponse.coins) {
        self.point += [videoResponse.coins intValue];
        [userDefaluts setValue:[NSString stringWithFormat:@"%d",self.point] forKey:ErnedPoints];
        [userDefaluts synchronize];
        [self updatepointsEarned];
    }
}

- (void)onVideoSkiped {
    [self showAlertWithMessage:@"Video is skipped"];
}

- (void)onVideoClosed {
    [self showAlertWithMessage:@"Video is closed"];

}

#pragma mark - Orienation

- (NSUInteger)supportedInterfaceOrientations
{
    if (self.appdelegate.deviceType == iPhone4s || self.appdelegate.deviceType == iPhone5 || self.appdelegate.deviceType == iPhone5s) {
        return UIInterfaceOrientationMaskPortrait;
    }
    return UIInterfaceOrientationMaskAll;
}

@end
