//
//  VideoSansAutoViewController.m
//  PokktManager
//
//  Created by Pokkt on 3/11/15.
//  Copyright (c) 2015 Pokkt. All rights reserved.
//

#import "VideoSansAutoViewController.h"
#import "AppDelegate.h"
#import "PokktManager.h"
#import "PokktController.h"
#import "VideoResponse.h"

#define ErnedPoints @"Points"
#define userDefaluts [NSUserDefaults standardUserDefaults]

@interface VideoSansAutoViewController ()<PokktDelegate>
@property (nonatomic, strong) AppDelegate *appdelegate;

@property (nonatomic ,strong) PokktManager *manager;
@property (nonatomic) int point;

@end

@implementation VideoSansAutoViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    self.appdelegate = [UIApplication sharedApplication].delegate;
    self.manager = [PokktManager sharedInstance];
    [self.manager setDebugger:YES];
    [self.manager setDefaultSkipTime:10];
    [self.manager setPokktDelegate:self];
    [self.manager setPresentView:self];
    [self updatepointsEarned];
}

-(void)viewWillAppear:(BOOL)animated{
    [super viewWillAppear:animated];
    [self.navigationController setNavigationBarHidden:YES];   //it hides
    if (![self.manager isVideoAvailable])
    {
        [self showButton:NO];
    }
    else
    {
        [self showButton:YES];
    }
}

-(void)viewWillDisappear:(BOOL)animated{
    [super viewWillDisappear:animated];
    [self.navigationController setNavigationBarHidden:NO];    // it shows
    
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

#pragma mark - Button Action

- (IBAction)videoButtonActions:(UIButton *)sender {
    if (sender.tag == 1)
    {
        [self checkVideoCache];
    }
    else if (sender.tag == 2)
    {
        [self.manager playVideoCampaign:YES];
    }
    else if (sender.tag == 3)
    {
        [self.manager playVideoCampaign:NO];
    }
    else if(sender.tag == 4)
    {
        if (![self.manager isVideoAvailable])
        {
            [self performSegueWithIdentifier:@"StaticPage" sender:self];
        }
        else
        {
            [self.manager playVideoCampaign:NO];
        }
    }
}

- (void)checkVideoCache {
    if (![self.manager isVideoAvailable])
    {
        [self.manager cacheVideoCampaign];
    }
    else
    {
        [self showButton:YES];
        [self.manager cacheVideoCampaign];
    }
}

- (void)showButton:(BOOL)show {
    self.incentVdoBtn.hidden = !show;
    self.nonIncentVdoBtn.hidden = !show;

}

#pragma mark - Private Methods 

- (void)updatepointsEarned {
    if([userDefaluts objectForKey:ErnedPoints]) {
        self.point = [[userDefaluts objectForKey:ErnedPoints] intValue];
        self.pointNumLbl.text = [NSString stringWithFormat:@"Points earned : %d",self.point];
    }
}

- (void)showAlertWithMessage:(NSString *)msg {
    UIAlertView *alert = [[UIAlertView alloc]initWithTitle:@"" message:msg delegate:nil cancelButtonTitle:@"OK" otherButtonTitles:nil];
    [alert show];
}

#pragma mark - Pokkt Delegates 

- (void)didFinishedVideoDownload:(BOOL)isFinished {
    [self showButton:YES];
    [self.incentVdoBtn setTitle:[NSString stringWithFormat:@"Play Incent Vdo To Earn %@",self.manager.videoVC] forState:UIControlStateNormal];
}

- (void)didFailedVideoDownload:(NSError *)error {
    [self showButton:NO];
}

- (void)onVideoClosed:(BOOL)isClosed {
    [self showAlertWithMessage:@"Video is closed"];
}

- (void)onVideoCompleated:(BOOL)isCompleated {
    [self showAlertWithMessage:@"Video is compleated"];
}

- (void)onVideoDisplayed  {
    [self showAlertWithMessage:@"Video is displayed"];
}

- (void)onVideoGratified:(VideoResponse *)videoResponse {
    if([userDefaluts objectForKey:ErnedPoints]) {
        self.point = [[userDefaluts objectForKey:ErnedPoints] intValue];
    }
    if (videoResponse.coins) {
        self.point += [videoResponse.coins intValue];
        [userDefaluts setValue:[NSString stringWithFormat:@"%d",self.point] forKey:ErnedPoints];
        [userDefaluts synchronize];
        [self updatepointsEarned];
    }
    
}

- (void)onVideoSkiped {
    [self showAlertWithMessage:@"Video is skip"];
}

#pragma mark - Orienation

- (NSUInteger)supportedInterfaceOrientations
{
    if (self.appdelegate.deviceType == iPhone4s || self.appdelegate.deviceType == iPhone5 || self.appdelegate.deviceType == iPhone5s) {
        return UIInterfaceOrientationMaskPortrait;
    }
    return UIInterfaceOrientationMaskAll;
}

@end
